// $Id$

/***************************************************************************
 *   Copyright (C) 2004 by Thomas Fischer                                  *
 *   fischer@unix-ag.uni-kl.de                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <qlabel.h>
#include <qmultilineedit.h>
#include <qlineedit.h>
#include <qlayout.h>
#include <kdialogbase.h>
#include <klocale.h>

#include <bibtexstring.h>

#include "kbibtexstringwidget.h"

KBibTeXStringWidget::KBibTeXStringWidget( BibTeXString *string, QWidget *parent, const char *name )
        : QWidget( parent, name ), m_string( string )
{
    setupGUI();
    getStringData();
}


KBibTeXStringWidget::~KBibTeXStringWidget()
{}

void KBibTeXStringWidget::setupGUI()
{
    setMinimumWidth( 384 );
    QVBoxLayout * layout = new QVBoxLayout( this, 0, KDialog::spacingHint() );

    QLabel *label = new QLabel( i18n( "String &id:" ), this );
    layout->addWidget( label );
    label->show();
    ledit = new QLineEdit( this );
    layout->addWidget( ledit );
    ledit->show();
    label->setBuddy( ledit );

    label = new QLabel( i18n( "String &value:" ), this );
    layout->addWidget( label );
    label->show();
    mledit = new QMultiLineEdit( this );
    layout->addWidget( mledit );
    mledit->show();
    label->setBuddy( mledit );
}

void KBibTeXStringWidget::setStringData()
{
    QString text = ledit->text();
    m_string->setId( text );
    text = mledit->text();
    m_string->setValue( text );
}

void KBibTeXStringWidget::getStringData()
{
    ledit->setText( m_string->id() );
    mledit->setText( m_string->value() );
}


QDialog::DialogCode KBibTeXStringWidget::execute( BibTeXString *string, const QString& caption, QWidget *parent, const char *name )
{
    KDialogBase * dlg = new KDialogBase( parent, name, true, caption, KDialogBase::Ok | KDialogBase::Cancel );
    KBibTeXStringWidget* ui = new KBibTeXStringWidget( string, dlg, "kbibtexstringwidget" );

    dlg->setMainWidget( ui );
    QDialog::DialogCode result = ( QDialog::DialogCode ) dlg->exec();
    if ( result == QDialog::Accepted )
        ui->setStringData();

    delete( ui );
    delete( dlg );

    return result;
}

#include "kbibtexstringwidget.moc"
